package com.shanp.push;

import android.app.Application;
import android.content.Context;
import android.util.Log;

import com.taobao.accs.ACCSClient;
import com.taobao.accs.AccsClientConfig;
import com.taobao.agoo.TaobaoRegister;
import com.umeng.commonsdk.UMConfigure;
import com.umeng.message.IUmengRegisterCallback;
import com.umeng.message.PushAgent;
import com.umeng.message.UTrack;
import com.umeng.message.api.UPushSettingCallback;
import com.umeng.message.common.inter.ITagManager;
import com.umeng.message.tag.TagManager;

import org.android.agoo.honor.HonorRegister;
import org.android.agoo.huawei.HuaWeiRegister;
import org.android.agoo.oppo.OppoRegister;
import org.android.agoo.vivo.VivoRegister;
import org.android.agoo.xiaomi.MiPushRegistar;

import java.util.List;

/**
 * shanpin_lxw
 * 2019/4/25
 */
public class PushUtil {

    private static String ALIAS = "";
    private static boolean mInitStatus = false;

    public static void preInit(Context context, String key, String secret) {
        try {
            //解决推送消息显示乱码的问题
            AccsClientConfig.Builder builder = new AccsClientConfig.Builder();
            builder.setAppKey("umeng:" + key);
            builder.setAppSecret(secret);
            builder.setTag(AccsClientConfig.DEFAULT_CONFIGTAG);
            ACCSClient.init(context, builder.build());
            TaobaoRegister.setAccsConfigTag(context, AccsClientConfig.DEFAULT_CONFIGTAG);
        } catch (Exception e) {
            Log.d("SHANP-PUSH", "preInit error : " + e.getMessage());
            e.printStackTrace();
        }
    }

    public static void initConfig(Context context, String key, String channel, String secret) {
        UMConfigure.init(context, key, channel, UMConfigure.DEVICE_TYPE_PHONE, secret);
    }

    public static void init(Context context, String alias) {
        PushAgent mPushAgent = PushAgent.getInstance(context);
        mPushAgent.register(new IUmengRegisterCallback() {

            @Override
            public void onSuccess(String deviceToken) {
                //注册成功会返回device token
                Log.d("SHANP-PUSH", "token success : " + deviceToken);
            }

            @Override
            public void onFailure(String s, String s1) {
                Log.d("SHANP-PUSH", "token error : " + s);
            }
        });
        ALIAS = alias;
        mInitStatus = true;
    }

    public static void registerDeviceChanel(
            Context context,
            String miId, String miKey,
            String oppoKey, String oppoScrcet) {
        MiPushRegistar.register(context, miId, miKey);
        HuaWeiRegister.register((Application) context.getApplicationContext());
        OppoRegister.register(context, oppoKey, oppoScrcet);
        VivoRegister.register(context);
        HonorRegister.register(context);
    }

    public static void bind(Context context, String uid) {
        bind(context, ALIAS, uid);
    }

    public static void bind(Context context, String alias, String uid) {
        PushAgent mPushAgent = PushAgent.getInstance(context);
        mPushAgent.setAlias(uid, alias, new UTrack.ICallBack() {
            @Override
            public void onMessage(boolean isSuccess, String message) {
                Log.d("SHANP-PUSH", isSuccess + " - " + message);
            }
        });
    }

    public static void unBind(Context context, String uid) {
        unBind(context, ALIAS, uid);
    }

    public static void unBind(Context context, String alias, String uid) {
        PushAgent mPushAgent = PushAgent.getInstance(context);
        mPushAgent.deleteAlias(uid, alias,
                new UTrack.ICallBack() {
                    @Override
                    public void onMessage(boolean isSuccess, String message) {
                        Log.d("SHANP-PUSH", isSuccess + " - " + message);
                    }
                });
    }

    public static void setTag(Context context, final String tag) {
        PushAgent mPushAgent = PushAgent.getInstance(context);
        final TagManager manager = mPushAgent.getTagManager();
        manager.getTags(new TagManager.TagListCallBack() {
            @Override
            public void onMessage(boolean b, List<String> list) {
                if (b && list != null) {
                    if (list.size() == 1 && tag.equals(list.get(0))) {
                        return;
                    }
                    String[] array = (String[]) list.toArray();
                    manager.deleteTags(new TagManager.TCallBack() {
                        @Override
                        public void onMessage(boolean b, ITagManager.Result result) {
                            Log.d("SHANP-PUSH", b + " - " + result.errors);
                            manager.addTags(new TagManager.TCallBack() {
                                @Override
                                public void onMessage(boolean b, ITagManager.Result result) {
                                    Log.d("SHANP-PUSH", b + " - " + result.errors);
                                }
                            }, tag);
                        }
                    }, array);
                }
            }
        });
    }

    public static void onAppStart(Context context) {
        if (mInitStatus) {
            PushAgent.getInstance(context).onAppStart();
        }
    }

    public static void enable(Context context) {
        PushAgent.getInstance(context).enable(new UPushSettingCallback() {
            @Override
            public void onSuccess() {
                Log.d("SHANP-PUSH", "PUSH ENABLE SUCCESS");
            }

            @Override
            public void onFailure(String s, String s1) {
                Log.d("SHANP-PUSH", "PUSH ENABLE " + s + " - " + s1);
            }
        });
    }

    public static void disable(Context context) {
        PushAgent.getInstance(context).disable(new UPushSettingCallback() {
            @Override
            public void onSuccess() {
                Log.d("SHANP-PUSH", "PUSH DISABLE SUCCESS");
            }

            @Override
            public void onFailure(String s, String s1) {
                Log.d("SHANP-PUSH", "PUSH DISABLE " + s + " - " + s1);
            }
        });
    }
}
