package com.shanp.sms;

import android.text.TextUtils;
import android.util.Log;

import com.shanp.base.util.EncryptionUtil;
import com.shanp.base.util.GsonUtil;
import com.shanp.sms.model.SmsRespones;
import com.shanp.sms.net.DefaultNetClientImpl;
import com.shanp.sms.net.NetClient;

import java.io.File;
import java.io.InputStream;
import java.net.URLEncoder;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * Leexw
 * 17/1/9
 */
class SmsNetClient {

    static final int CODE_SUCCESS = 200;
    private static final int CODE_NET_ERROR = 10500;
    public static final int CODE_KEY_ERROR = 10004;
    private static final String MSG_NET_ERROR = "网络连接不稳定，请稍后重试";

    private static NetClient mNetClient;
    private static String mSignKey;

    static {
        mSignKey = "sp_service";
        mNetClient = new DefaultNetClientImpl();
        mNetClient.setRequestProperty("My-User-Agent", SmsConfig.SMS_NET_AGENT);
    }

    public static SmsRespones get(String url, Map<String, Object> params) {
        Log.d("ShanpSms", "api : " + url + " ---> " + params);
        String param = getRequestParamAndSign(params);
        if (!TextUtils.isEmpty(param)) {
            url = url + "?" + param;
        }
        Log.d("ShanpSms", "url : " + url);
        String json = mNetClient.get(url);
        return toResponse(json);
    }

    public static SmsRespones post(String url, Map<String, Object> params) {
        Log.d("ShanpSms", "api : " + url + " ---> " + params);
        String param = getRequestParamAndSign(params);
        String json = mNetClient.post(url, param);
        return toResponse(json);
    }

    public static SmsRespones upload(String url, Map<String, Object> params, List<File> files) {
        Log.d("ShanpSms", "upload api : " + url + " ---> " + params);
        String json = mNetClient.upload(url, params, files);
        return toResponse(json);
    }

    static InputStream download(String url, Map<String, Object> params) {
        Log.d("ShanpSms", "download api : " + url);
        String param = getRequestParamAndSign(params);
        if (!TextUtils.isEmpty(param)) {
            url = url + "?" + param;
        }
        Log.d("ShanpSms", "url : " + url);
        return mNetClient.download(url);
    }

    private static SmsRespones toResponse(String json) {
        Log.d("ShanpSms", "response : " + json);
        SmsRespones response = GsonUtil.fromJson(json, SmsRespones.class);
        if (response == null) {
            response = error();
        }
        return response;
    }

    private static SmsRespones error() {
        return new SmsRespones(CODE_NET_ERROR, MSG_NET_ERROR);
    }

    private static String getRequestParamAndSign(Map<String, Object> paramMap) {
        if (paramMap == null) {
            paramMap = new HashMap<>();
        }
        paramMap.put("spTimestamp", System.currentTimeMillis());
        Set<String> keySet = paramMap.keySet();
        String[] keyArray = keySet.toArray(new String[0]);
        Arrays.sort(keyArray);
        StringBuilder sb = new StringBuilder();
        StringBuilder result = new StringBuilder();
        for (String key : keyArray) {
            // 参数值为null，不参与签名
            Object value = paramMap.get(key);
            if (value == null) {
                continue;
            }
            sb.append(key).append("=").append(value.toString().trim()).append("&");
            result.append(key).append("=").append(encode(value)).append("&");
        }
        sb.append("spSignKey=").append(mSignKey);
        String sign = EncryptionUtil.encryption(sb.toString()).toUpperCase();
        result.append("&spSign=").append(sign);
        return result.toString();
    }

    private static String encode(Object value) {
        String result = value.toString();
        try {
            result = URLEncoder.encode(result, "UTF-8");
        } catch (Exception e) {
            e.printStackTrace();
        }
        return result.trim();
    }
}
