package com.shanp.sms;

import android.app.Activity;
import android.widget.PopupWindow;

import com.shanp.base.rx.TaskObserver;

import io.reactivex.Observable;
import io.reactivex.disposables.Disposable;
import io.reactivex.internal.disposables.ListCompositeDisposable;

/**
 * shanpin_lxw
 * 2019/3/21
 */
class SmsTransmitter {

    private final ListCompositeDisposable mDisposables;
    private OnSmsActionListener mOnSmsActionListener;
    private Activity mActivity;
    private SmsVerifyPop pop;
    private SmsModel config;

    private String mPath;
    private String mUpdateImagePath;
    private int mValidBtnRid;
    private int mInvalidBtnRid;

    SmsTransmitter(String path) {
        this(null, path);
    }

    private SmsTransmitter(Activity activity, String path) {
        this.mDisposables = new ListCompositeDisposable();

        this.mActivity = activity;
        this.mPath = path;
    }

    void setOnSmsActionListener(OnSmsActionListener listener) {
        this.mOnSmsActionListener = listener;
    }

    void setSmsVerifyPopBtnStyle(int valid, int invalid) {
        this.mValidBtnRid = valid;
        this.mInvalidBtnRid = invalid;
    }

    public void close() {
        mDisposables.clear();
    }

    void updateActivity(Activity activity) {
        this.mActivity = activity;
    }

    void getSms(String phone) {
        Observable<SmsModel> task = SmsRepository.getInstance().getSmsConfig(phone);
        Disposable disposable = task.subscribeWith(new TaskObserver<SmsModel>() {

            @Override
            public void onSuccess(SmsModel smsModel) {
                super.onSuccess(smsModel);
                config = smsModel;
                if (config.getLevel() == SmsConfig.LEVEL_VERIFY_IMG) {
                    showVerifyPop();
                    getVerifyImage();
                } else {
                    send(null);
                }
            }

            @Override
            public void onFailure(String msg) {
                super.onFailure(msg);
                if (mOnSmsActionListener != null) {
                    mOnSmsActionListener.onError(msg);
                }
            }
        });
        mDisposables.add(disposable);
    }

    private void send(String imgCode) {
        Observable<String> task = SmsRepository.getInstance().send(config.getTicketNo(), config.getSign(), imgCode);
        Disposable disposable = task.subscribeWith(new TaskObserver<String>() {
            @Override
            public void onSuccess(String value) {
                if (pop != null) {
                    pop.dismiss();
                }
                if (mOnSmsActionListener != null) {
                    mOnSmsActionListener.onSuccess(config.getTicketNo());
                }
            }

            @Override
            public void onFailure(String msg) {
                super.onFailure(msg);
                if (mOnSmsActionListener != null) {
                    mOnSmsActionListener.onError(msg);
                }
            }
        });
        mDisposables.add(disposable);
    }

    private void getVerifyImage() {
        long mUpdateImageNum = System.currentTimeMillis();
        mUpdateImagePath = mPath + mUpdateImageNum;
        Observable<String> task = SmsRepository.getInstance().getSmsImg(config.getTicketNo(), mUpdateImagePath);
        Disposable disposable = task.subscribeWith(new TaskObserver<String>() {
            @Override
            public void onSuccess(String value) {
                showVerifyImage();
            }

            @Override
            public void onFailure(String msg) {
                super.onFailure(msg);

            }
        });
        mDisposables.add(disposable);
    }

    private void showVerifyPop() {
        if (pop == null) {
            pop = new SmsVerifyPop(mActivity);
            pop.setBtnStyle(mValidBtnRid, mInvalidBtnRid);
            pop.setOnSmsVerifyPopListener(new SmsVerifyPop.OnSmsVerifyPopListener() {
                @Override
                public void ok(String code) {
                    send(code);
                }

                @Override
                public void update() {
                    getVerifyImage();
                }
            });
            pop.setOnDismissListener(new PopupWindow.OnDismissListener() {
                @Override
                public void onDismiss() {
                    pop.lighten();
                    if (mOnSmsActionListener != null) {
                        mOnSmsActionListener.onError(null);
                    }
                }
            });
        }
        pop.show(mUpdateImagePath);
    }

    private void showVerifyImage() {
        if (pop != null) {
            pop.setVerifyImage(mUpdateImagePath);
        }
    }
}
