package com.shanp.sms;

import android.app.Activity;
import android.graphics.drawable.ColorDrawable;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.view.Gravity;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.TextView;

import com.shanp.base.image.ImageLoadUtil;
import com.shanp.base.pop.AbstractPop;

/**
 * shanpin_lxw
 * 2019/3/19
 */
public class SmsVerifyPop extends AbstractPop implements View.OnClickListener {

    private ImageView mVerifyIv;
    private EditText mVerifyEt;
    private TextView mVerifyUpdateTv;
    private Button mVerifyBtn;

    private OnSmsVerifyPopListener mOnSmsVerifyPopListener;

    private int mValidBtnRid;
    private int mInvalidBtnRid;

    public SmsVerifyPop(Activity activity) {
        super(activity);
        setContentView(R.layout.pop_sms_verify, ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT);

        this.setOutsideTouchable(true);
        this.setFocusable(true);
        this.setBackgroundDrawable(new ColorDrawable());
        this.setOnDismissListener(new OnDismissListener() {
            @Override
            public void onDismiss() {
                lighten();
            }
        });

        mVerifyIv = mLayout.findViewById(R.id.iv_sms_verify);
        mVerifyEt = mLayout.findViewById(R.id.et_sms_verify);
        mVerifyUpdateTv = mLayout.findViewById(R.id.tv_sms_verify_update);
        mVerifyBtn = mLayout.findViewById(R.id.btn_sms_verify);

        mVerifyEt.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {

            }

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count) {
                boolean verify = !TextUtils.isEmpty(s) && s.length() == 4;
                setLoginEnable(verify);
            }

            @Override
            public void afterTextChanged(Editable s) {

            }
        });
        mLayout.findViewById(R.id.iv_sms_verify_close).setOnClickListener(this);
        mVerifyUpdateTv.setOnClickListener(this);
        mVerifyBtn.setOnClickListener(this);
        setLoginEnable(false);
    }

    public void setOnSmsVerifyPopListener(OnSmsVerifyPopListener listener) {
        this.mOnSmsVerifyPopListener = listener;
    }

    public void show(String path) {
        hideSoftInput();
        darken();

        setVerifyImage(path);
        this.showAtLocation(mLayout, Gravity.CENTER, 0, 0);
    }

    public void setBtnStyle(int valid, int invalid) {
        this.mValidBtnRid = valid;
        this.mInvalidBtnRid = invalid;
        mVerifyBtn.setBackgroundResource(mVerifyBtn.isEnabled() ? mValidBtnRid : mInvalidBtnRid);
    }

    public void setVerifyImage(String path) {
        ImageLoadUtil.load(mActivity, path, mVerifyIv);
        mVerifyUpdateTv.setEnabled(true);
        mVerifyUpdateTv.setText(getString(R.string.shanp_sms_pop_update));
    }

    private void setLoginEnable(boolean b) {
        if (mVerifyBtn.isEnabled() == b) {
            return;
        }
        mVerifyBtn.setEnabled(b);
        if (b) {
            mVerifyBtn.setBackgroundResource(mValidBtnRid);
        } else {
            mVerifyBtn.setBackgroundResource(mInvalidBtnRid);
        }
    }

    @Override
    public void onClick(View v) {
        int id = v.getId();
        if (id == R.id.btn_sms_verify) {
            if (mOnSmsVerifyPopListener != null) {
                mOnSmsVerifyPopListener.ok(mVerifyEt.getText().toString());
            }
        } else if (id == R.id.tv_sms_verify_update) {
            if (mOnSmsVerifyPopListener != null) {
                mVerifyUpdateTv.setEnabled(false);
                mVerifyUpdateTv.setText(getString(R.string.shanp_sms_pop_update_ing));
                mOnSmsVerifyPopListener.update();
            }
        } else if (id == R.id.iv_sms_verify_close) {
            lighten();
            dismiss();
        }
    }

    public interface OnSmsVerifyPopListener {
        void ok(String code);

        void update();
    }
}
