package com.shanp.widget.wheel;

import java.util.ArrayList;
import java.util.List;

public abstract class WheelBaseAdapter implements WheelDataSet {

    // 滚动列表的适配器
    private WheelListView.OnWheelSelectListener mFirstSelectListener;
    private WheelListView.OnWheelSelectListener mSecondSelectListener;
    private WheelListView.OnWheelSelectListener mThirdSelectListener;
    private WheelDataSet mDataSet;

    protected List<WheelItem> mFirstList = null;
    protected List<WheelItem> mSecondList = null;
    protected List<WheelItem> mThirdList = null;

    protected int mFirstIndex = 0;
    protected int mSecondIndex = 0;
    protected int mThirdIndex = 0;

    public WheelBaseAdapter() {
        mFirstSelectListener = new WheelListView.OnWheelSelectListener() {
            @Override
            public void select(int index) {
                onFirstSelect(index);
            }
        };
        mSecondSelectListener = new WheelListView.OnWheelSelectListener() {
            @Override
            public void select(int index) {
                onSecondSelect(index);
            }
        };
        mThirdSelectListener = new WheelListView.OnWheelSelectListener() {
            @Override
            public void select(int index) {
                onThirdSelect(index);
            }
        };
    }

    public WheelListView.OnWheelSelectListener getOnFirstSelectListener() {
        return mFirstSelectListener;
    }

    public WheelListView.OnWheelSelectListener getOnSecondSelectListener() {
        return mSecondSelectListener;
    }

    public WheelListView.OnWheelSelectListener getOnThirdSelectListener() {
        return mThirdSelectListener;
    }

    public void setDataSet(WheelDataSet dataSet) {
        this.mDataSet = dataSet;
    }

    public abstract void init();

    public abstract void onFirstSelect(int index);

    public abstract void onSecondSelect(int index);

    public abstract void onThirdSelect(int index);

    public void getLastIndex() {
    }

    public void setLastIndex() {
    }

    @Override
    public void setFirstList(List<WheelItem> data) {
        mFirstList = data;
        mDataSet.setFirstList(setWheelListStyle(data));
    }

    @Override
    public void setSecondList(List<WheelItem> data) {
        mSecondList = data;
        mDataSet.setSecondList(setWheelListStyle(data));
    }

    @Override
    public void setThirdList(List<WheelItem> data) {
        mThirdList = data;
        mDataSet.setThirdList(setWheelListStyle(data));
    }

    @Override
    public void setFirstIndex(int index) {
        this.mFirstIndex = index;
        mDataSet.setFirstIndex(index);
    }

    @Override
    public void setSecondIndex(int index) {
        this.mSecondIndex = index;
        mDataSet.setSecondIndex(index);
    }

    @Override
    public void setThirdIndex(int index) {
        this.mThirdIndex = index;
        mDataSet.setThirdIndex(index);
    }

    @Override
    public void setShowWheelNum(int num) {
        mDataSet.setShowWheelNum(num);
    }

    public WheelItem getFirstResult() {
        if (mFirstList == null || mFirstList.size() <= 0) {
            return null;
        }
        return mFirstList.get(mFirstIndex);
    }

    public WheelItem getSecondResult() {
        if (mSecondList == null || mSecondList.size() <= 0) {
            return null;
        }
        return mSecondList.get(mSecondIndex);
    }

    public WheelItem getThirdResult() {
        if (mThirdList == null || mThirdList.size() <= 0) {
            return null;
        }
        return mThirdList.get(mThirdIndex);
    }

    /**
     * 设置列表变成滚动选择控件，前后留两格空的形式
     *
     * @param list
     */
    protected List<WheelItem> setWheelListStyle(List<WheelItem> list) {
        List<WheelItem> styleList = new ArrayList<WheelItem>(list);
        WheelItem empty = new WheelItem(null, "");
        styleList.add(0, empty);
        styleList.add(0, empty);
        styleList.add(empty);
        styleList.add(empty);
        return styleList;
    }

}
