package com.shanp.widget.wheel;

import android.content.Context;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.RelativeLayout;

import java.util.List;

public class WheelChooseView extends RelativeLayout implements WheelDataSet {

    private Context mContext;

    private WheelBaseAdapter mAdapter;
    // 滚动列表
    private WheelListView mFirstWlv;
    private WheelListView mSecondWlv;
    private WheelListView mThirdWlv;
    // 滚动列表的适配器
    private WheelAdapter mFirstWa;
    private WheelAdapter mSecondWa;
    private WheelAdapter mThirdWa;

    public WheelChooseView(Context context, AttributeSet attrs) {
        super(context, attrs);
        mContext = context;
        LayoutInflater inflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        inflater.inflate(R.layout.widget_wheel_choose, this);
        initView();
    }

    public void initView() {
        /* 初始化3个滚动选列表 */
        mFirstWlv = (WheelListView) findViewById(R.id.wlv_first);
        mSecondWlv = (WheelListView) findViewById(R.id.wlv_second);
        mThirdWlv = (WheelListView) findViewById(R.id.wlv_third);

        mFirstWa = new WheelAdapter(mContext, null);
        mSecondWa = new WheelAdapter(mContext, null);
        mThirdWa = new WheelAdapter(mContext, null);

        mFirstWlv.setAdapter(mFirstWa);
        mSecondWlv.setAdapter(mSecondWa);
        mThirdWlv.setAdapter(mThirdWa);
    }

    public void setAdapter(WheelBaseAdapter adapter) {
        reset();
        this.mAdapter = adapter;
        mAdapter.setDataSet(this);
        mFirstWlv.setOnWheelSelectListener(mAdapter.getOnFirstSelectListener());
        mSecondWlv.setOnWheelSelectListener(mAdapter.getOnSecondSelectListener());
        mThirdWlv.setOnWheelSelectListener(mAdapter.getOnThirdSelectListener());
        mAdapter.init();
    }

    public WheelBaseAdapter getAdapter() {
        return mAdapter;
    }

    /**
     * 重置坐标
     */
    public void reset() {
        mFirstWlv.resetView();
        mSecondWlv.resetView();
        mThirdWlv.resetView();
    }

    @Override
    public void setFirstList(List<WheelItem> data) {
        mFirstWa.setData(data);
        mFirstWlv.setAdapter(mFirstWa);
    }

    @Override
    public void setSecondList(List<WheelItem> data) {
        mSecondWa.setData(data);
        mSecondWlv.setAdapter(mSecondWa);
    }

    @Override
    public void setThirdList(List<WheelItem> data) {
        mThirdWa.setData(data);
        mThirdWlv.setAdapter(mThirdWa);
    }

    @Override
    public void setFirstIndex(int index) {
        mFirstWlv.setSelection(index);
    }

    @Override
    public void setSecondIndex(int index) {
        mSecondWlv.setSelection(index);
    }

    @Override
    public void setThirdIndex(int index) {
        mThirdWlv.setSelection(index);
    }

    @Override
    public void setShowWheelNum(int num) {
        mThirdWlv.setVisibility(View.GONE);
        mSecondWlv.setVisibility(View.GONE);
        mFirstWlv.setVisibility(View.GONE);
        switch (num) {
            case 3:
                mThirdWlv.setVisibility(View.VISIBLE);
            case 2:
                mSecondWlv.setVisibility(View.VISIBLE);
            case 1:
                mFirstWlv.setVisibility(View.VISIBLE);
                break;
            default:
                break;
        }
    }

}