package com.shanp.widget.wheel;

import android.annotation.SuppressLint;
import android.content.Context;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.widget.AbsListView;
import android.widget.AbsListView.OnScrollListener;
import android.widget.ListView;

/**
 * 滚动选择的ListView
 *
 * @author Leexw
 */
public class WheelListView extends ListView implements OnScrollListener {

    private final static String TAG = "WheelListView";

    //滚动选择监听接口
    private OnWheelSelectListener mSelectListener = null;
    //当前显示第一条的序号
    private int firstVisibleItemPosition = 0;
    //上一次第一条显示的序号
    private int lastFirstPosttion = -1;

    /**
     * 构造方法
     *
     * @param context 上下文内容
     * @param attrs
     */
    public WheelListView(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.setOverScrollMode(View.OVER_SCROLL_NEVER);
        this.setOnScrollListener(this);
    }

    /**
     * 设置监听接口
     *
     * @param listener
     */
    public void setOnWheelSelectListener(OnWheelSelectListener listener) {
        this.mSelectListener = listener;
    }

    /**
     * 选择一条时，滚动到
     */
    public void selectOneItem() {
        this.setSelection(firstVisibleItemPosition);
        //这里的判断作用是：如果滑动了两次，都是选择的一个城市就不做操作.
        if (lastFirstPosttion != firstVisibleItemPosition) {
            if (mSelectListener != null) {
                mSelectListener.select(getFirstVisiblePosition());
            }
            lastFirstPosttion = firstVisibleItemPosition;
        }
    }

    @Override
    public void onScrollStateChanged(AbsListView view, int scrollState) {
        switch (scrollState) {
            case SCROLL_STATE_IDLE:
                selectOneItem();
                break;
            default:
                break;
        }
    }

    @Override
    public void onScroll(AbsListView view, int firstVisibleItem,
                         int visibleItemCount, int totalItemCount) {
        firstVisibleItemPosition = this.getFirstVisiblePosition();
    }

    @SuppressLint("ClickableViewAccessibility")
    public boolean onTouchEvent(MotionEvent ev) {
        switch (ev.getAction()) {
            case MotionEvent.ACTION_UP:
                selectOneItem();
                break;
            default:
                break;
        }
        return super.onTouchEvent(ev);
    }

    public interface OnWheelSelectListener {
        void select(int index);
    }

    public void resetView() {
        lastFirstPosttion = -1;
    }

}
