package com.shanp.base.activity;

import android.app.Activity;
import android.os.Bundle;
import android.view.View;
import android.widget.Toast;

import androidx.appcompat.app.AppCompatActivity;

import com.shanp.base.rx.EventReceiver;
import com.shanp.base.rx.MaybeTaskObserver;
import com.shanp.base.rx.RxSchedulerHelper;
import com.shanp.base.rx.SingleTaskObserver;
import com.shanp.base.rx.TaskObserver;

import io.reactivex.Flowable;
import io.reactivex.Maybe;
import io.reactivex.Observable;
import io.reactivex.Single;
import io.reactivex.disposables.Disposable;
import io.reactivex.internal.disposables.ListCompositeDisposable;

/**
 * Leexw
 * 16/12/22
 */
public abstract class BaseActivity extends AppCompatActivity {

    private ListCompositeDisposable mTasks;

    protected Activity mContext;
    private boolean mActRunning;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        mContext = this;
        if (mTasks == null || mTasks.isDisposed()) {
            mTasks = new ListCompositeDisposable();
        }
    }

    @Override
    protected void onDestroy() {
        if (mTasks != null) {
            mTasks.dispose();
        }
        super.onDestroy();
    }

    @Override
    public void onWindowFocusChanged(boolean hasFocus) {
        super.onWindowFocusChanged(hasFocus);
        if (hasFocus) {
            if (!mActRunning) {
                onActivityRunning();
                mActRunning = true;
            } else {
                onActivityRunningAgain();
            }
        }
    }

    protected void onActivityRunning() {
    }

    protected void onActivityRunningAgain() {
    }

    protected void recycle(Disposable disposable) {
        mTasks.add(disposable);
    }

    protected void clearDisposable() {
        mTasks.clear();
    }

    @SuppressWarnings("unchecked")
    protected <E extends View> E find(int rid) {
        return (E) findViewById(rid);
    }

    protected void setOnClickListener(View.OnClickListener listener, View... views) {
        if (views == null) {
            return;
        }
        for (View v : views) {
            v.setOnClickListener(listener);
        }
    }

    protected int getColorByRid(int resId) {
        return getResources().getColor(resId);
    }

    protected void toast(String text) {
        Toast.makeText(getApplicationContext(), text, Toast.LENGTH_LONG).show();
    }

    private void hold(Disposable task) {
        if (mTasks != null) {
            mTasks.add(task);
        }
    }

    protected <T> void execute(Observable<T> task, TaskObserver<T> observer) {
        hold(observer);
        task.compose(RxSchedulerHelper.<T>io_main())
                .subscribe(observer);
    }

    protected <T> void execute(Maybe<T> task, MaybeTaskObserver<T> observer) {
        hold(observer);
        task.compose(RxSchedulerHelper.<T>io_main_maybe())
                .subscribe(observer);
    }

    protected <T> void execute(Single<T> task, SingleTaskObserver<T> observer) {
        hold(observer);
        task.compose(RxSchedulerHelper.<T>io_main_single())
                .subscribe(observer);
    }

    protected <T> void register(Flowable<T> event, EventReceiver<T> receiver) {
        hold(receiver);
        event.subscribe(receiver);
    }
}
