package com.shanp.base.fragment;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.view.View;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;

import com.shanp.base.rx.EventReceiver;
import com.shanp.base.rx.RxSchedulerHelper;
import com.shanp.base.rx.TaskObserver;

import io.reactivex.Flowable;
import io.reactivex.Observable;
import io.reactivex.disposables.Disposable;
import io.reactivex.internal.disposables.ListCompositeDisposable;
import io.reactivex.observers.DisposableObserver;

/**
 * Leexw
 * 16/12/22
 */
public abstract class BaseFragment extends Fragment {

    private ListCompositeDisposable mTasks;

    protected Activity mContext;
    protected View mView;

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        if (mTasks == null || mTasks.isDisposed()) {
            mTasks = new ListCompositeDisposable();
        }
    }

    @Override
    public void onAttach(@NonNull Context context) {
        super.onAttach(context);
        mContext = getActivity();
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        if (mTasks != null) {
            mTasks.dispose();
        }
    }

    protected void recycle(Disposable disposable) {
        mTasks.add(disposable);
    }

    @SuppressWarnings("unchecked")
    protected <E extends View> E find(int rid) {
        if (mView == null) {
            return null;
        }
        return (E) mView.findViewById(rid);
    }

    protected void setOnClickListener(View.OnClickListener listener, View... views) {
        if (views == null) {
            return;
        }
        for (View v : views) {
            v.setOnClickListener(listener);
        }
    }

    protected int getColorByRid(int resId) {
        return getResources().getColor(resId);
    }

    protected void toast(String text) {
        Toast.makeText(mContext.getApplicationContext(), text, Toast.LENGTH_SHORT).show();
    }

    private void hold(Disposable task) {
        if (mTasks != null) {
            mTasks.add(task);
        }
    }

    protected <T> void execute(Observable<T> task, TaskObserver<T> observer) {
        hold(observer);
        task.compose(RxSchedulerHelper.<T>io_main())
                .subscribe(observer);
    }

    protected <T> void register(Flowable<T> event, EventReceiver<T> receiver) {
        hold(receiver);
        event.subscribe(receiver);
    }
}
