package com.shanp.base.image;

import android.app.Activity;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;

import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;

/**
 * shanpin_lxw
 * 17/2/28
 */

public class ImageUtil {

    private static final int MAX_WIDTH = 1080;
    private static final int MAX_HEIGHT = 1920;

    private static final String THUMBNAIL = ".thumbnail";

    public static Bitmap getBitmapByUri(Activity activity, Uri uri) {
        Bitmap bitmap;
        try {
            BitmapFactory.Options options = new BitmapFactory.Options();
            options.inJustDecodeBounds = true;
            InputStream input = activity.getContentResolver().openInputStream(uri);
            BitmapFactory.decodeStream(input, null, options);
            if (input != null) {
                input.close();
            }

            BitmapFactory.Options op = new BitmapFactory.Options();
            op.inSampleSize = getCompressSize(options.outWidth, options.outHeight);
            input = activity.getContentResolver().openInputStream(uri);
            bitmap = BitmapFactory.decodeStream(input, null, op);
            if (input != null) {
                input.close();
            }
        } catch (Exception e) {
            bitmap = null;
        }
        return bitmap;
    }

    private static int getCompressSize(int width, int height) {
        int size = 1;
        if (width > height && width > MAX_WIDTH) {
            size = width / MAX_WIDTH;
        } else if (width <= height && height > MAX_HEIGHT) {
            size = height / MAX_HEIGHT;
        }
        size = size <= 0 ? 1 : size;
        return size;
    }

    public static Bitmap scaledBitmap(Bitmap bitmap, int maxWidth) {
        int w = bitmap.getWidth();
        if (maxWidth > 0 && w > maxWidth) {
            int h = bitmap.getHeight();
            float scale = (float) w / h;
            int maxHeight = (int) (maxWidth / scale);
            return Bitmap.createScaledBitmap(bitmap, maxWidth, maxHeight, false);
        }
        return bitmap;
    }

    public static Bitmap cropCenterBitmap(Bitmap bitmap, float scale, int maxWidth) {
        int w = bitmap.getWidth();
        int h = bitmap.getHeight();
        int width = w > h ? h : w;
        int height = (int) (width / scale);
        int x = (w - width) / 2;
        int y = (h - height) / 2;
        Bitmap result = Bitmap.createBitmap(bitmap, x, y, width, height);
        if (maxWidth > 0 && width > maxWidth) {
            int maxHeight = (int) (maxWidth / scale);
            return Bitmap.createScaledBitmap(result, maxWidth, maxHeight, false);
        }
        return result;
    }

    public static boolean saveBitmap(Bitmap bitmap, String path) {
        if (bitmap == null) {
            return false;
        }
        try {
            File file = new File(path);
            FileOutputStream out = new FileOutputStream(file);
            bitmap.compress(Bitmap.CompressFormat.JPEG, 100, out);
            out.flush();
            out.close();
            return true;
        } catch (Exception e) {
            return false;
        }
    }

    public static String getThumbnailImageUrl(String url) {
        String result = url;
        int pointIndex = result.lastIndexOf(".");
        String prefix = result.substring(0, pointIndex);
        String suffix = result.substring(pointIndex);
        result = prefix + THUMBNAIL + suffix;
        return result;
    }
}
