package com.shanp.base.image.glide;

import android.content.Context;
import android.graphics.drawable.Drawable;
import android.widget.ImageView;

import com.bumptech.glide.Glide;
import com.bumptech.glide.RequestBuilder;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.bumptech.glide.load.resource.bitmap.CenterCrop;
import com.shanp.base.image.BitmapTarget;
import com.shanp.base.image.ImageLoad;
import com.shanp.base.image.ImageShowType;
import com.shanp.base.image.ImageSize;
import com.shanp.base.util.MetricUtil;

/**
 * Leexw
 * 17/1/17
 */
public class GlideImageLoad implements ImageLoad {

    private BlurTransformation mBlurTransformation;
    private RoundedCornersTransformation mRoundedCornersTransformation4;
    private RoundedCornersTransformation mRoundedCornersTransformation8;
    private RoundedCornersTransformation mRoundedCornersTransformationTop8;

    private void transform(Context context, RequestBuilder<Drawable> builder, int... types) {
        if (types == null) {
            return;
        }
        for (int type : types) {
            switch (type) {
                case ImageShowType.CENTER_CROP:
                    builder.centerCrop();
                    break;
                case ImageShowType.FIT_CENTER:
                    builder.fitCenter();
                    break;
                case ImageShowType.CIRCLE:
                    builder.circleCrop();
                    break;
                case ImageShowType.BLUR:
                    if (mBlurTransformation == null) {
                        mBlurTransformation = new BlurTransformation();
                    }
                    builder.transform(mBlurTransformation);
                    break;
                case ImageShowType.CORNERS_4:
                    if (mRoundedCornersTransformation4 == null) {
                        int corners = MetricUtil.dip2Px(context, 4);
                        mRoundedCornersTransformation4 = new RoundedCornersTransformation(corners, 0);
                    }
                    builder.transform(mRoundedCornersTransformation4);
                    break;
                case ImageShowType.CROP_CORNERS_4:
                    if (mRoundedCornersTransformation4 == null) {
                        int corners = MetricUtil.dip2Px(context, 4);
                        mRoundedCornersTransformation4 = new RoundedCornersTransformation(corners, 0);
                    }
                    builder.transform(new CenterCrop(), mRoundedCornersTransformation4);
                    break;
                case ImageShowType.CORNERS_8:
                    if (mRoundedCornersTransformation8 == null) {
                        int corners = MetricUtil.dip2Px(context, 8);
                        mRoundedCornersTransformation8 = new RoundedCornersTransformation(corners, 0);
                    }
                    builder.transform(mRoundedCornersTransformation8);
                    break;
                case ImageShowType.CROP_CORNERS_8:
                    if (mRoundedCornersTransformation8 == null) {
                        int corners = MetricUtil.dip2Px(context, 8);
                        mRoundedCornersTransformation8 = new RoundedCornersTransformation(corners, 0);
                    }
                    builder.transform(new CenterCrop(), mRoundedCornersTransformation8);
                    break;
                case ImageShowType.CORNERS_TOP_8:
                    if (mRoundedCornersTransformationTop8 == null) {
                        int corners = MetricUtil.dip2Px(context, 8);
                        mRoundedCornersTransformationTop8 = new RoundedCornersTransformation(corners, 0, RoundedCornersTransformation.CornerType.TOP);
                    }
                    builder.transform(mRoundedCornersTransformationTop8);
                    break;
            }
        }
    }

    @Override
    public void load(Context context, String url, ImageView view, int placeholder, int... types) {
        load(context, url, view, null, placeholder, types);
    }

    @Override
    public void load(Context context, String url, ImageView view, ImageSize size, int placeholder, int... types) {
        RequestBuilder<Drawable> builder = Glide.with(context)
                .load(url)
                .placeholder(placeholder)
                .skipMemoryCache(true)
                .diskCacheStrategy(DiskCacheStrategy.DATA);
        if (size != null) {
            builder = builder.override(size.getWidth(), size.getHeight());
        }
        transform(context, builder, types);
        builder.into(view);
    }

    @Override
    public void drawable(Context context, int drawableId, ImageView view, int placeholder, int... types) {
        RequestBuilder<Drawable> builder = Glide.with(context)
                .load(drawableId)
                .dontAnimate()
                .skipMemoryCache(true)
                .diskCacheStrategy(DiskCacheStrategy.NONE);
        transform(context, builder, types);
        builder.into(view);
    }

    @Override
    public void getBitmap(Context context, String url, BitmapTarget target, int... types) {
        getBitmap(context, url, null, target, types);
    }

    @Override
    public void getBitmap(Context context, String url, ImageSize size, BitmapTarget target, int... types) {
        RequestBuilder<Drawable> builder = Glide.with(context)
                .load(url)
                .skipMemoryCache(true)
                .diskCacheStrategy(DiskCacheStrategy.DATA);
        if (size != null) {
            builder = builder.override(size.getWidth(), size.getHeight());
        }
        transform(context, builder, types);
        builder.into(target);
    }

}
