package com.shanp.base.pop;

import android.app.Activity;
import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.view.inputmethod.InputMethodManager;
import android.widget.PopupWindow;

/**
 * shanpin_lxw
 * 17/2/14
 */
public abstract class AbstractPop extends PopupWindow {

    protected Activity mActivity;
    protected View mLayout;

    private InputMethodManager imm;

    public AbstractPop(Activity activity) {
        this.mActivity = activity;
    }

    protected void setContentView(int layoutRid, int width, int height) {
        LayoutInflater inflater = LayoutInflater.from(mActivity);
        mLayout = inflater.inflate(layoutRid, null, false);
        setContentView(mLayout);
        setWidth(width);
        setHeight(height);
    }

    protected void hideSoftInput() {
        if (imm == null) {
            imm = (InputMethodManager) mActivity.getApplicationContext()
                    .getSystemService(Context.INPUT_METHOD_SERVICE);
        }
        View view = mActivity.getWindow().getDecorView().getRootView();
        if (view != null) {
            imm.hideSoftInputFromWindow(view.getWindowToken(), 0);
        }
    }

    protected void darken() {
        Window window = mActivity.getWindow();
        WindowManager.LayoutParams lp = window.getAttributes();
        lp.alpha = 0.4f;
        window.addFlags(WindowManager.LayoutParams.FLAG_DIM_BEHIND);
        window.setAttributes(lp);
    }

    public void lighten() {
        Window window = mActivity.getWindow();
        WindowManager.LayoutParams lp = window.getAttributes();
        lp.alpha = 1f;
        window.clearFlags(WindowManager.LayoutParams.FLAG_DIM_BEHIND);
        window.setAttributes(lp);
    }

    public Context getContext() {
        return getContentView().getContext();
    }

    public String getString(int rid) {
        return mActivity.getString(rid);
    }

    public int getColorByRid(int rid) {
        return mActivity.getResources().getColor(rid);
    }

    public <T extends View> T find(int id) {
        return mLayout.findViewById(id);
    }
}
