package com.shanp.base.rx;

import android.content.DialogInterface;

import com.shanp.base.view.Loadable;

import java.lang.ref.WeakReference;

import io.reactivex.disposables.Disposable;

/**
 * 继承回调抽象类，包含自动弹框功能
 *
 * @param <T> 返回类型
 */
public abstract class LoadSingleTaskObserver<T> extends SingleTaskObserver<T> {

    private WeakReference<Loadable> mAutoLoaderReference;
    private boolean isAutoHide;

    public LoadSingleTaskObserver(Loadable loadable) {
        this(loadable, true);
    }

    public LoadSingleTaskObserver(Loadable loadable, boolean auto) {
        loadable.getDialog().setOnCancelListener(new DialogInterface.OnCancelListener() {
            @Override
            public void onCancel(DialogInterface dialog) {
                Disposable disposable = LoadSingleTaskObserver.this;
                if (!disposable.isDisposed()) {
                    disposable.dispose();
                }
            }
        });
        mAutoLoaderReference = new WeakReference<>(loadable);
        this.isAutoHide = auto;
    }

    @Override
    protected void onStart() {
        super.onStart();
        Loadable loadable = mAutoLoaderReference.get();
        if (loadable != null) {
            loadable.showLoadDialog();
        }
    }

    @Override
    public void onSuccess(T t) {
        if (isAutoHide) {
            hide();
        }
    }

    @Override
    public void onError(Throwable e) {
        hide();
        super.onError(e);
    }

    private void hide() {
        Loadable loadable = mAutoLoaderReference.get();
        if (loadable != null) {
            loadable.hideLoadDialog();
        }
    }
}
