package com.shanp.base.rx;

import io.reactivex.BackpressureStrategy;
import io.reactivex.Flowable;
import io.reactivex.Observable;
import io.reactivex.internal.util.AppendOnlyLinkedArrayList;
import io.reactivex.subjects.PublishSubject;
import io.reactivex.subjects.Subject;

/**
 * shanpin_lxw
 * 17/2/13
 */

public class RxBus {

    private static volatile RxBus INSTANCE;
    private final Subject bus;

    public RxBus() {
        bus = PublishSubject.create().toSerialized();
    }

    public static RxBus getInstance() {
        if (INSTANCE == null) {
            synchronized (RxBus.class) {
                if (INSTANCE == null) {
                    INSTANCE = new RxBus();
                }
            }
        }
        return INSTANCE;
    }

    public void post(Object obj) {
        //noinspection unchecked
        bus.onNext(obj);
    }

    public <T> Observable<T> toObservable(final Class<T> clazz) {
        //noinspection unchecked
        return bus
                .filter(new AppendOnlyLinkedArrayList.NonThrowingPredicate() {
                    @Override
                    public boolean test(Object o) {
                        return o != null;
                    }
                })
                .ofType(clazz)
                .compose(RxSchedulerHelper.io_main());
    }

    public <T> Flowable<T> toFlowable(final Class<T> clazz) {
        //noinspection unchecked
        return bus
                .filter(new AppendOnlyLinkedArrayList.NonThrowingPredicate() {
                    @Override
                    public boolean test(Object o) {
                        return o != null;
                    }
                })
                .ofType(clazz)
                .compose(RxSchedulerHelper.io_main())
                .toFlowable(BackpressureStrategy.LATEST);
    }
}
