package com.shanp.base.rx;

import android.util.Log;

import io.reactivex.observers.DisposableObserver;

/**
 * 回调抽象类
 * 继承Rxjava DisposableObserver subscribeActual
 * onError 和 onComplete 会自动 dispose 取消订阅，不用手动取消，详情见 ObservableCreate
 * onError 后不会调用 onComplete
 *
 * @param <T> 返回类型
 * @author Leexw
 * @date 2019-10-18
 */
public abstract class TaskObserver<T> extends DisposableObserver<T> {

    @Override
    public void onNext(T t) {
        onSuccess(t);
    }

    @Override
    public void onError(Throwable e) {
        onFailure(e.getMessage());
        onFinish();
    }

    @Override
    public void onComplete() {
        onFinish();
    }

    public void onSuccess(T t) {

    }

    public void onFailure(String msg) {

    }

    public void onFinish() {

    }
}
